==> dart_json_mapper-1.1.7.tar.gz: test/test.errors.dart <==
part of json_mapper.test;

class UnAnnotated {}

enum Sex { Male, Female }
const sexTypeValues = ["__female", "__male"];

@jsonSerializable
class UnAnnotatedEnumField {
  Sex sex = Sex.Female;
}

@jsonSerializable
class WrongAnnotatedEnumField {
  @JsonProperty(enumValues: sexTypeValues)
  Sex sex = Sex.Female;
}

@jsonSerializable
class MyCar {
  @JsonProperty(name: 'modelName')
  String model;

  @JsonProperty(enumValues: Color.values)
  Color color;

  MyCar replacement;

  MyCar(this.model, this.color);
}

typedef ErrorGeneratorFunction = dynamic Function();
dynamic catchError(ErrorGeneratorFunction errorGenerator) {
  var targetError;
  try {
    errorGenerator();
  } catch (error) {
    targetError = error;
  }
  return targetError;
}

testErrorHandling() {
  group("[Verify error handling]", () {
    test("Circular reference detection during serialization", () {
      final MyCar car = MyCar('VW', Color.Blue);
      car.replacement = car;
      expect(catchError(() => JsonMapper.serialize(car)),
          TypeMatcher<CircularReferenceError>());
    });

    test("Missing annotation on class", () {
      expect(catchError(() => JsonMapper.serialize(UnAnnotated())),
          TypeMatcher<MissingAnnotationOnTypeError>());
    });

    test("Missing annotation on Enum field", () {
      expect(catchError(() => JsonMapper.serialize(UnAnnotatedEnumField())),
          TypeMatcher<MissingEnumValuesError>());
    });

    test("Wrong enumValues in annotation on Enum field", () {
      final json = '{"sex":"Sex.Female"}';
      expect(catchError(() {
        WrongAnnotatedEnumField target = JsonMapper.deserialize(json);
      }), TypeMatcher<MissingEnumValuesError>());
    });

    test("Missing target type for deserialization", () {
      expect(catchError(() => JsonMapper.deserialize("{}")),
          TypeMatcher<MissingTypeForDeserializationError>());
    });
  });
}

==> dart_json_mapper-1.2.1.tar.gz: test/test.errors.dart <==
part of json_mapper.test;

class UnAnnotated {}

enum Sex { Male, Female }
const sexTypeValues = ["__female", "__male"];

@jsonSerializable
class UnAnnotatedEnumField {
  Sex sex = Sex.Female;
}

@jsonSerializable
class WrongAnnotatedEnumField {
  @JsonProperty(enumValues: sexTypeValues)
  Sex sex = Sex.Female;
}

typedef ErrorGeneratorFunction = dynamic Function();
dynamic catchError(ErrorGeneratorFunction errorGenerator) {
  var targetError;
  try {
    errorGenerator();
  } catch (error) {
    targetError = error;
  }
  return targetError;
}

testErrorHandling() {
  group("[Verify error handling]", () {
    test("Circular reference detection during serialization", () {
      final Car car = Car('VW', Color.Blue);
      car.replacement = car;
      expect(catchError(() => JsonMapper.serialize(car)),
          TypeMatcher<CircularReferenceError>());
    });

    test("Missing annotation on class", () {
      expect(catchError(() => JsonMapper.serialize(UnAnnotated())),
          TypeMatcher<MissingAnnotationOnTypeError>());
    });

    test("Missing annotation on Enum field", () {
      expect(catchError(() => JsonMapper.serialize(UnAnnotatedEnumField())),
          TypeMatcher<MissingEnumValuesError>());
    });

    test("Wrong enumValues in annotation on Enum field", () {
      final json = '{"sex":"Sex.Female"}';
      expect(catchError(() {
        JsonMapper.deserialize<WrongAnnotatedEnumField>(json);
      }), TypeMatcher<MissingEnumValuesError>());
    });

    test("Missing target type for deserialization", () {
      expect(catchError(() => JsonMapper.deserialize("{}")),
          TypeMatcher<MissingTypeForDeserializationError>());
    });
  });
}
